@@ -29,7 +29,7 @@ class PythonSearchCli:
 
     @staticmethod
     def new_project(project_name: str):
-        """ Create a new project in the current directory with the given name  """
+        """Create a new project in the current directory with the given name"""
         from python_search.init_project import InitializeProject
 
         InitializeProject().initialize(project_name)
@@ -52,6 +52,7 @@ class PythonSearchCli:
                 return
 
         self.configuration = configuration
+        self.run_key = EntryRunner(self.configuration).run
 
     def search(self):
         """
@@ -61,20 +62,16 @@ class PythonSearchCli:
 
         Search(self.configuration).run()
 
-    def run_key(self):
-        import sys
-
-        print(sys.version_info)
-        return EntryRunner(self.configuration).run_key
 
     def copy_entry_content(self, key: str):
         """
         Copies the content of the provided key to the clipboard.
         Used by fzf to provide Ctrl-c functionality.
         """
-        from python_search.interpreter.interpreter import Interpreter
+        from python_search.interpreter.interpreter_matcher import \
+            InterpreterMatcher
 
-        Interpreter.build_instance(self.configuration).clipboard(key)
+        InterpreterMatcher.build_instance(self.configuration).clipboard(key)
 
     def copy_key_only(self, key_str: str):
         """
@@ -103,7 +100,7 @@ class PythonSearchCli:
     def register_clipboard(self):
         from python_search.entry_capture.register_new import RegisterNew
 
-        return RegisterNew(self.configuration).from_clipboard()
+        return RegisterNew(self.configuration).launch_ui()
 
     def register_new(self):
         from python_search.entry_capture.register_new import RegisterNew
@@ -167,9 +164,9 @@ class PythonSearchCli:
         return Utils(self.configuration)
 
     def google_it(self, query):
-        from python_search.interpreter.url import Url
+        from python_search.interpreter.url import UrlInterpreter
 
-        Url(
+        UrlInterpreter(
             {
                 "url": f"http://www.google.com/search?q={query}",
             }
@@ -195,6 +192,9 @@ def _error_handler(e):
 
     raise e
 
+def _run_key_bin():
+    import fire
+    fire.Fire(PythonSearchCli().run_key)
 
 def main():
     import fire
