@@ -2,15 +2,15 @@ import logging
 
 from python_search.apps.browser import Browser
 from python_search.exceptions import CommandDoNotMatchException
-from python_search.interpreter.base import BaseEntry
-from python_search.interpreter.cmd import CmdEntry
+from python_search.interpreter.base import BaseInterpreter
+from python_search.interpreter.cmd import CmdInterpreter
 
 
-class Url(BaseEntry):
+class UrlInterpreter(BaseInterpreter):
     def __init__(self, cmd, context=None):
         self.context = context
 
-        if type(cmd) == str and Url.is_url(cmd):
+        if type(cmd) == str and UrlInterpreter.is_url(cmd):
             self.cmd = {"url": cmd}
             return
 
@@ -30,7 +30,7 @@ class Url(BaseEntry):
         final_cmd["cmd"] = shell_cmd
 
         print(f"Final command={final_cmd}")
-        return CmdEntry(final_cmd, self.context).interpret_default()
+        return CmdInterpreter(final_cmd, self.context).interpret_default()
 
     def copiable_part(self):
         return self.cmd["url"]
